@@ -1,7 +1,7 @@
 package PERLANCAR::Module::List;
 
-our $DATE = '2016-03-15'; # DATE
-our $VERSION = '0.003004'; # VERSION
+our $DATE = '2016-03-17'; # DATE
+our $VERSION = '0.003005'; # VERSION
 
 #IFUNBUILT
 # use strict;
@@ -62,7 +62,7 @@ sub list_modules($$) {
 							$entry)) {
 					my $newpfx = $prefix.$entry."::";
 					next if exists $seen_prefixes{$newpfx};
-					$results{$newpfx} //= $return_path ? ($all ? [@{ $results{$newpfx} || [] }, "$dir/$entry/"] : "$dir/$entry/") : undef
+					$results{$newpfx} = $return_path ? ($all ? [@{ $results{$newpfx} || [] }, "$dir/$entry/"] : "$dir/$entry/") : undef
 						if ($all && $return_path || !exists($results{$newpfx})) && $list_prefixes;
 					push @prefixes, $newpfx if $recurse;
 				}
@@ -95,7 +95,7 @@ PERLANCAR::Module::List - A fork of Module::List
 
 =head1 VERSION
 
-This document describes version 0.003004 of PERLANCAR::Module::List (from Perl distribution PERLANCAR-Module-List), released on 2016-03-15.
+This document describes version 0.003005 of PERLANCAR::Module::List (from Perl distribution PERLANCAR-Module-List), released on 2016-03-17.
 
 =head1 DESCRIPTION
 
